@@ -5,15 +5,15 @@ use warnings;
 require Exporter ;
 use bytes;
 
-use IO::Compress::Base 2.087 ;
+use IO::Compress::Base 2.088 ;
 
-use IO::Compress::Base::Common  2.087 qw(createSelfTiedObject);
-use IO::Compress::Adapter::Lzf  2.087 ;
+use IO::Compress::Base::Common  2.088 qw(createSelfTiedObject);
+use IO::Compress::Adapter::Lzf  2.088 ;
 #use Compress::Lzf ;
 
 our ($VERSION, @ISA, @EXPORT_OK, %EXPORT_TAGS, $LzfError);
 
-$VERSION = '2.087';
+$VERSION = '2.088';
 $LzfError = '';
 
 @ISA    = qw( IO::Compress::Base Exporter );
@@ -155,7 +155,6 @@ IO::Compress::Lzf - Write lzf files/buffers
     binmode $z
     fileno $z
     close $z ;
- 
 
 =head1 DESCRIPTION
 
@@ -187,7 +186,8 @@ The functional interface needs Perl5.005 or better.
 =head2 lzf $input_filename_or_reference => $output_filename_or_reference [, OPTS]
 
 C<lzf> expects at least two parameters,
-C<$input_filename_or_reference> and C<$output_filename_or_reference>.
+C<$input_filename_or_reference> and C<$output_filename_or_reference>
+and zero or more optional parameters (see L</Optional Parameters>)
 
 =head3 The C<$input_filename_or_reference> parameter
 
@@ -296,9 +296,9 @@ in C<$output_filename_or_reference> as a concatenated series of compressed data
 
 =head2 Optional Parameters
 
-Unless specified below, the optional parameters for C<lzf>,
-C<OPTS>, are the same as those used with the OO interface defined in the
-L</"Constructor Options"> section below.
+The optional parameters for the one-shot function C<lzf>
+are (for the most part) identical to those used with the OO interface defined in the
+L</"Constructor Options"> section. The exceptions are listed below
 
 =over 5
 
@@ -366,6 +366,22 @@ Defaults to 0.
 
 =head2 Examples
 
+Here are a few example that show the capabilities of the module.
+
+=head3 Streaming
+
+This very simple command line example demonstrates the streaming capabilities of the module.
+The code reads data from STDIN, compresses it, and writes the compressed data to STDOUT.
+
+    $ echo hello world | perl -MIO::Compress::Lzf=lzf -e 'lzf \*STDIN => \*STDOUT' >output.lzf
+
+The special filename "-" can be used as a standin for both C<\*STDIN> and C<\*STDOUT>,
+so the above can be rewritten as
+
+    $ echo hello world | perl -MIO::Compress::Lzf=lzf -e 'lzf "-" => "-"' >output.lzf
+
+=head3 Compressing a file from the filesystem
+
 To read the contents of the file C<file1.txt> and write the compressed
 data to the file C<file1.txt.lzf>.
 
@@ -377,6 +393,8 @@ data to the file C<file1.txt.lzf>.
     lzf $input => "$input.lzf"
         or die "lzf failed: $LzfError\n";
 
+=head3 Reading from a Filehandle and writing to an in-memory buffer
+
 To read from an existing Perl filehandle, C<$input>, and write the
 compressed data to a buffer, C<$buffer>.
 
@@ -391,6 +409,8 @@ compressed data to a buffer, C<$buffer>.
     lzf $input => \$buffer
         or die "lzf failed: $LzfError\n";
 
+=head3 Compressing multiple files
+
 To compress all files in the directory "/my/home" that match "*.txt"
 and store the compressed data in the same directory
 
@@ -465,7 +485,7 @@ return undef.
 
 =head2 Constructor Options
 
-C<OPTS> is any combination of the following options:
+C<OPTS> is any combination of zero or more the following options:
 
 =over 5
 
@@ -718,6 +738,12 @@ Same as doing this
 
 =head1 EXAMPLES
 
+=head1 SUPPORT
+
+General feedback/questions/bug reports should be sent to 
+L<https://github.com/pmqs/IO-Compress-Lzf/issues> (preferred) or
+L<https://rt.cpan.org/Public/Dist/Display.html?Name=IO-Compress-Lzf>.
+
 =head1 SEE ALSO
 
 L<Compress::Zlib>, L<IO::Compress::Gzip>, L<IO::Uncompress::Gunzip>, L<IO::Compress::Deflate>, L<IO::Uncompress::Inflate>, L<IO::Compress::RawDeflate>, L<IO::Uncompress::RawInflate>, L<IO::Compress::Bzip2>, L<IO::Uncompress::Bunzip2>, L<IO::Compress::Lzma>, L<IO::Uncompress::UnLzma>, L<IO::Compress::Xz>, L<IO::Uncompress::UnXz>, L<IO::Compress::Lzip>, L<IO::Uncompress::UnLzip>, L<IO::Compress::Lzop>, L<IO::Uncompress::UnLzop>, L<IO::Uncompress::UnLzf>, L<IO::Compress::Zstd>, L<IO::Uncompress::UnZstd>, L<IO::Uncompress::AnyInflate>, L<IO::Uncompress::AnyUncompress>
